[**고급 옵션**](./introduction.md) > **언어 코드** _(현재)_

---

#### Google

소스 <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, GPT-4o로 정리됨.

| 중국어 레이블 | 레이블 | `Language Code` |
| --- | --- | --- |
| 암하라어 | Amharic | `am` |
| 아랍어 | Arabic | `ar` |
| 바스크어 | Basque | `eu` |
| 孟加拉语 | Bengali | `bn` |
| 영어(영국) | English (UK) | `en-GB` |
| 포르투갈어(브라질) | Portuguese (Brazil) | `pt-BR` |
| 불가리아어 | Bulgarian | `bg` |
| 카탈로니아어 | Catalan | `ca` |
| 체로키어 | Cherokee | `chr` |
| 크로아티아어 | Croatian | `hr` |
| 체코어 | Czech | `cs` |
| 덴마크어 | Danish | `da` |
| 네덜란드어 | Dutch | `nl` |
| 영어(미국) | English (US) | `en` |
| 에스토니아어 | Estonian | `et` |
| 菲律宾语 | Filipino | `fil` |
| 芬兰어 | Finnish | `fi` |
| 프랑스어 | French | `fr` |
| 독일어 | German | `de` |
| 그리스어 | Greek | `el` |
| 구자라트어 | Gujarati | `gu` |
| 希伯来语 | Hebrew | `iw` |
| 힌디어 | Hindi | `hi` |
| 헝가리어 | Hungarian | `hu` |
| 아이슬란드어 | Icelandic | `is` |
| 인도네시아어 | Indonesian | `id` |
| 이탈리아어 | Italian | `it` |
| 일본어 | Japanese | `ja` |
| 칸나다어 | Kannada | `kn` |
| 한국어 | Korean | `ko` |
| 立陶宛语 | Lithuanian | `lt` |
| 리투아니아어 | Lithuanian | `lt` |
| 马来语 | Malay | `ms` |
| 말라얄람어 | Malayalam | `ml` |
| 마라티어 | Marathi | `mr` |
| 노르웨이어 | Norwegian | `no` |
| 폴란드어 | Polish | `pl` |
| 포르투갈어(포르투갈) | Portuguese (Portugal) | `pt-PT` |
| 루마니아어 | Romanian | `ro` |
| 러시아어 | Russian | `ru` |
| 세르비아어 | Serbian | `sr` |
| 한국어 (대한민국) | Korean (South Korea) | `ko-KR` |
| 슬로바키아어 | Slovak | `sk` |
| 슬로베니아어 | Slovenian | `sl` |
| 스페인어 | Spanish | `es` |
| 스와힐리어 | Swahili | `sw` |
| 스웨덴어 | Swedish | `sv` |
| 타밀어 | Tamil | `ta` |
| 泰卢固语 | Telugu | `te` |
| 테이블 형식의 번역 결과입니다:

| 태국어 | Thai | `th` |
| 중국어(대만) | Chinese (Taiwan) | `zh-TW` |
| 土耳其어 | Turkish | `tr` |
| Urdu | `ur` |
| 乌克兰语 | Ukrainian | `uk` |
| 베트남어 | Vietnamese | `vi` |
| 웨일스어 | Welsh | `cy` |

#### DeepL

원본 <https://developers.deepl.com/docs/resources/supported-languages>, GPT-4o 정리.

| 중국어 레이블 | 레이블 | `Language Code` | 지원 여부 |
| --- | --- | --- | --- |
| 아랍어 | Arabic | `AR` | `source`, `target` |
| 불가리아어 | Bulgarian | `BG` | `source`, `target` |
| 체코어 | Czech | `CS` | `source`, `target` |
| 덴마크어 | Danish | `DA` | `source`, `target` |
| 독일어 | German | `DE` | `source`, `target` |
| 그리스어 | Greek | `EL` | `source`, `target` |
| 영어 | English | `EN` | `source`, `target` |
| 영어 (영국) | English (British) | `EN-GB` | `target` |
| 영어(미국) | English (American) | `EN-US` | `target` |
| 스페인어 | Spanish | `ES` | `source`, `target` |
| 에스토니아어 | Estonian | `ET` | `source`, `target` |
| 핀란드어 | Finnish | `FI` | `source`, `target` |
| 프랑스어 | French | `FR` | `source`, `target` |
| 헝가리어 | Hungarian | `HU` | `source`, `target` |
| 인도네시아어 | Indonesian | `ID` | `source`, `target` |
| 이탈리아어 | Italian | `IT` | `source`, `target` |
| 일본어 | Japanese | `JA` | `source`, `target` |
| 한국어 | Korean | `KO` | `source`, `target` |
| 리투아니아어 | Lithuanian | `LT` | `source`, `target` |
| 라트비아어 | Latvian | `LV` | `source`, `target` |
| 노르웨이 보크몰어 | Norwegian Bokmål | `NB` | `source`, `target` |
| 네덜란드어 | Dutch | `NL` | `source`, `target` |
| 폴란드어 | Polish | `PL` | `source`, `target` |
| 포르투갈어 | Portuguese | `PT` | `source`, `target` |
| 포르투갈어(브라질) | Portuguese (Brazilian) | `PT-BR` | `target` |
| 포르투갈어(유럽) | Portuguese (European) | `PT-PT` | `target` |
| 루마니아어 | Romanian | `RO` | `source`, `target` |
| 러시아어 | Russian | `RU` | `source`, `target` |
| 슬로바키아어 | Slovak | `SK` | `source`, `target` |
| 슬로베니아어 | Slovenian | `SL` | `source`, `target` |
| 스웨덴어 | Swedish | `SV` | `source`, `target` |
| 터키어 | Turkish | `TR` | `source`, `target` |
| 우크라이나어 | Ukrainian | `UK` | `source`, `target` |
| 中文 | Chinese | `ZH` | `source`, `target` |
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>이 페이지의 일부 내용은 GPT에 의해 번역되었으며 오류가 포함될 수 있습니다.</small></h6>